/* 
 * This file is part of the MorphAL plugin project for OpenJUMP.
 *
 * The MorphAL plugin project aims at providing some tools to analyse specifically
 * historical vector data even if they can be also used to analyse current data.
 * 
 * These tools have been developped during the ALPAGE project and are described
 * in the documentation -- detailed installation instructions are also provided
 * with this documentation --provided with this code or accessible through
 * the following links:
 * http://lamop.univ-paris1.fr/alpage_english/index.php/cartography (English version)
 * http://lamop.univ-paris1.fr/alpage/index.php/cartographie (French version)
 * 
 * For more information, feel free to visit: http://lamop.univ-paris1.fr/alpage
 * 
 * Copyright (C) 2010 ALPAGE
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * For more information, contact the ALPAGE team:
 * http://lamop.univ-paris1.fr/alpage_english/index.php/contact-us
 * 
 */
package fr.ign.cogit.alpage.morphal;

import com.vividsolutions.jump.workbench.plugin.Extension;
import com.vividsolutions.jump.workbench.plugin.PlugInContext;

import fr.ign.cogit.alpage.morphal.plugin.geometry.GeometryValidatorPlugin;
import fr.ign.cogit.alpage.morphal.plugin.linestring.LineStringCleaningPlugin;
import fr.ign.cogit.alpage.morphal.plugin.linestring.LineStringToSegmentsPlugin;
import fr.ign.cogit.alpage.morphal.plugin.linestring.SegmentOrientationPlugin;
import fr.ign.cogit.alpage.morphal.plugin.polygon.PolygonCharacterisationPlugin;
import fr.ign.cogit.alpage.morphal.plugin.polygon.PolygonCleaningPlugin;
import fr.ign.cogit.alpage.morphal.plugin.polygon.PolygonPerimeterAreaPlugin;
import fr.ign.cogit.alpage.morphal.plugin.polygon.PolygonToSegmentsPlugin;
import fr.ign.cogit.alpage.morphal.plugin.statistics.ClassificationIntegerDoublePlugin;

/** 
 * Install the MorphAL plugins in OpenJUMP
 * 
 * @author Eric Grosso - IGN / Laboratoire COGIT
 * 
 * @version 0.1 (2011-01-09)
 */
public class MorphALExtension extends Extension {
	
	@Override
	public String getName() {
		return "MorphAL Extension (Morphologic AnaLysis) -- ALPAGE project";
	}
	
	@Override
	public String getVersion() {
		return "0.1 (2011-01-09)";
	}
	
	public void configure(PlugInContext context) throws Exception {

		// Geometry generic
		new GeometryValidatorPlugin().initialize(context);

		// LineStrings and Segments
		new LineStringToSegmentsPlugin().initialize(context);
		new LineStringCleaningPlugin().initialize(context);
		new SegmentOrientationPlugin().initialize(context);

		// Polygons
		new PolygonCharacterisationPlugin().initialize(context);
		new PolygonCleaningPlugin().initialize(context);
		new PolygonToSegmentsPlugin().initialize(context);
		new PolygonPerimeterAreaPlugin().initialize(context);
		
		// Statistics
		new ClassificationIntegerDoublePlugin().initialize(context);
	}
	
}