/* 
 * This file is part of the MorphAL plugin project for OpenJUMP.
 *
 * The MorphAL plugin project aims at providing some tools to analyse specifically
 * historical vector data even if they can be also used to analyse current data.
 * 
 * These tools have been developped during the ALPAGE project and are described
 * in the documentation -- detailed installation instructions are also provided
 * with this documentation --provided with this code or accessible through
 * the following links:
 * http://lamop.univ-paris1.fr/alpage_english/index.php/cartography (English version)
 * http://lamop.univ-paris1.fr/alpage/index.php/cartographie (French version)
 * 
 * For more information, feel free to visit: http://lamop.univ-paris1.fr/alpage
 * 
 * Copyright (C) 2010 ALPAGE
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * For more information, contact the ALPAGE team:
 * http://lamop.univ-paris1.fr/alpage_english/index.php/contact-us
 * 
 */
package fr.ign.cogit.alpage.morphal.geometry;

import com.vividsolutions.jts.geom.Coordinate;
import com.vividsolutions.jts.geom.LineString;

/**  
 * Geometric methods others than methods dealing with
 * {@link com.vividsolutions.jts.geom.Point}, 
 * {@link com.vividsolutions.jts.geom.MultiPoint},
 * {@link LineString},
 * {@link com.vividsolutions.jts.geom.MultiLineString},
 * {@link com.vividsolutions.jts.geom.Polygon}
 * and {@link com.vividsolutions.jts.geom.MultiPolygon} types.
 * 
 * @author Eric Grosso - IGN / Laboratoire COGIT
 *
 * @version 0.1 (2011-01-09)
 */
public class GeometryUtil {

	/**
	 * Method to compare quickly if two {@link Coordinate}s have the same position.
	 * 
	 * @param coord the first coordinate to compare
	 * @param coord2 the second coordinate to compare
	 * @return true if the two coordinates are the same (at a geomtric level,
	 * not at an object level), otherwise false
	 */
	public static boolean compareCoordinate(Coordinate coord, Coordinate coord2) {
		if (coord.x != coord2.x) return false;
		if (coord.y != coord2.y) return false;
		return true;
	}
	
}