/* 
 * This file is part of the MorphAL plugin project for OpenJUMP.
 *
 * The MorphAL plugin project aims at providing some tools to analyse specifically
 * historical vector data even if they can be also used to analyse current data.
 * 
 * These tools have been developped during the ALPAGE project and are described
 * in the documentation -- detailed installation instructions are also provided
 * with this documentation --provided with this code or accessible through
 * the following links:
 * http://lamop.univ-paris1.fr/alpage_english/index.php/cartography (English version)
 * http://lamop.univ-paris1.fr/alpage/index.php/cartographie (French version)
 * 
 * For more information, feel free to visit: http://lamop.univ-paris1.fr/alpage
 * 
 * Copyright (C) 2010 ALPAGE
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * For more information, contact the ALPAGE team:
 * http://lamop.univ-paris1.fr/alpage_english/index.php/contact-us
 * 
 */
package fr.ign.cogit.alpage.morphal.ui.statistics;

import javax.swing.JFrame;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.ChartPanel;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.PlotOrientation;
import org.jfree.data.statistics.HistogramDataset;
import org.jfree.data.statistics.HistogramType;

import fr.ign.cogit.alpage.morphal.i18n.I18NPlug;

/** 
 * UI: Histogram frame building.
 * 
 * @author Eric Grosso - IGN / Laboratoire COGIT
 *
 * @version 0.1 (2011-01-09)
 */
public class Histogram extends JFrame {
	
	////////////////////////////////////////////////////////////////////////////////////
	// Internationalisation
		
	private final static String FREQUENCY = I18NPlug.getI18N("ui.statistics.histogram.frequency");
	private final static String STEP = I18NPlug.getI18N("ui.statistics.histogram.step");

	////////////////////////////////////////////////////////////////////////////////////
	
	private static final long serialVersionUID = 1L;

	/** 
	 * Default constructor.
	 * 
	 * @param title title of the histogram
	 * @param values values to represent
	 * @param step step of the histogram
	 * @param valuesName name of the values (e.g. "orientations")
	 */
	public Histogram(String title, double[] values, int step, String valuesName) {
		super(title);
		this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		initialise(values, step, valuesName);
	}
	
	/** 
	 * Initialisation.
	 * 
	 * @param values values to represent
	 * @param step step of the histogram (negative or null step will be considered as
	 * being equal to 1) 
	 * @param valuesName name of the values (e.g. "orientations")
	 */
	public void initialise(double[] values, int step, String valuesName) {
		if (step <= 0) step = 1;

		// Sort
		java.util.Arrays.sort(values);
		double min = values[0], max = values[values.length - 1];
		double extent = max - min;
		double nbStep = extent / step;
		int nbStepInteger = new Double(Math.ceil(nbStep)).intValue();
		
		HistogramDataset dataset = new HistogramDataset();
		dataset.setType(HistogramType.FREQUENCY);
		dataset.addSeries(valuesName, values, nbStepInteger);
		
		JFreeChart chart = ChartFactory.createHistogram(
				FREQUENCY + " " + valuesName + " - " + STEP + ": " + step, 
				null, 
				null, 
				dataset, 
				PlotOrientation.VERTICAL, 
				true, 
				false, 
				false
		);
		chart.getXYPlot().setForegroundAlpha(0.75f);
		
		ChartPanel chartPanel = new ChartPanel(chart);
		chartPanel.setPreferredSize(new java.awt.Dimension(500, 270));
		chartPanel.setMouseZoomable(true, false);
		this.setContentPane(chartPanel);
	}

}